jacinle.utils.uid
=================

.. automodule:: jacinle.utils.uid

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      gen_time_string
      gen_uuid4
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: gen_time_string

.. autofunction:: gen_uuid4


